import { Server } from 'socket.io'
import { TSocket } from '../../../utilities/Types'
import path from 'path'
import fs from 'fs'
import SpriteRepository from '../../../repositories/SpriteRepository'

interface IPayload {
  sprite: string
}

/**
 * Handle game master remove sprite event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
  socket.on('gm:sprite:remove', async (data: IPayload, callback: (response: boolean) => void) => {
    if (socket.character?.role !== 'gm') {
      return
    }

    try {
      await SpriteRepository.delete(data.sprite)

      // get root path
      const public_folder = path.join(process.cwd(), 'public', 'sprites')

      // remove the tile from the disk
      const finalFilePath = path.join(public_folder, data.sprite + '.png')
      fs.unlink(finalFilePath, (err) => {
        if (err) {
          console.log(err)
          callback(false)
          return
        }

        callback(true)
      })
    } catch (e) {
      console.log(e)
      callback(false)
    }
  })
}
