import { Server } from 'socket.io'
import { TSocket } from '../../../utilities/Types'
import SpriteRepository from '../../../repositories/SpriteRepository'
import { Sprite } from '@prisma/client'

interface IPayload {
  id: string
  name: string
  origin_x: number
  origin_y: number
}

/**
 * Handle game master sprite update event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
  socket.on('gm:sprite:update', async (data: IPayload, callback: (success: boolean) => void) => {
    if (socket.character?.role !== 'gm') {
      return
    }

    try {
      const sprite = await SpriteRepository.update(data.id, data.name, data.origin_x, data.origin_y)

      callback(true)
    } catch (error) {
      console.error(error)
      callback(false)
    }
  })
}
