import { Server } from 'socket.io'
import { TSocket } from '../../../utilities/Types'
import TileRepository from '../../../repositories/TileRepository'

interface IPayload {
  id: string
  name: string
  tags: string[]
}

/**
 * Handle game master tile update event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
  socket.on('gm:tile:update', async (data: IPayload, callback: (success: boolean) => void) => {
    if (socket.character?.role !== 'gm') {
      return
    }

    try {
      const Tile = await TileRepository.update(data.id, data.name, data.tags)

      callback(true)
    } catch (error) {
      console.error(error)
      callback(false)
    }
  })
}
