import { Server } from 'socket.io'
import { TSocket } from '../../../utilities/Types'
import ZoneRepository from '../../../repositories/ZoneRepository'
import ZoneManager from '../../../managers/ZoneManager'
import { Character, Zone } from '@prisma/client'

interface IPayload {
  name: string
  width: number
  height: number
}

/**
 * Handle game master zone create event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
  socket.on('gm:zone_editor:zone:create', async (data: IPayload, callback: (response: Zone[]) => void) => {
    if (socket.character?.role !== 'gm') {
      console.log(`---Character #${socket.character?.id} is not a game master.`)
      return
    }

    console.log(`---GM ${socket.character?.id} has created a new zone via zone editor.`)
    let zoneList: Zone[] = []
    try {
      const zone = await ZoneRepository.create(
        data.name,
        data.width,
        data.height,
        Array.from({ length: data.height }, () => Array.from({ length: data.width }, () => 'blank_tile'))
      )

      zoneList = await ZoneRepository.getAll()
      callback(zoneList)
      // send over zone and characters to socket
    } catch (e) {
      console.error(e)
      socket.emit('notification', { message: 'Failed to create zone.' })
      callback(zoneList)
    }
  })
}
