import { Server } from 'socket.io'
import { TSocket } from '../../../utilities/Types'
import ZoneRepository from '../../../repositories/ZoneRepository'
import ZoneManager from '../../../managers/ZoneManager'
import { Character, Zone, ZoneEventTile, ZoneObject } from '@prisma/client'

interface IPayload {
  zoneId: number
  name: string
  width: number
  height: number
  tiles: string[][]
  zoneEventTiles: ZoneEventTile[]
  zoneObjects: ZoneObject[]
}

/**
 * Handle game master zone update event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
  socket.on('gm:zone_editor:zone:update', async (data: IPayload) => {
    if (socket.character?.role !== 'gm') {
      console.log(`---Character #${socket.character?.id} is not a game master.`)
      return
    }

    console.log(`---GM ${socket.character?.id} has updated zone via zone editor.`)

    if (!data.zoneId) {
      console.log(`---Zone id not provided.`)
      return
    }

    try {
      let zone = await ZoneRepository.getById(data.zoneId)

      if (!zone) {
        console.log(`---Zone not found.`)
        return
      }

      await ZoneRepository.update(data.zoneId, data.name, data.width, data.height, data.tiles, data.zoneEventTiles, data.zoneObjects)

      zone = await ZoneRepository.getById(data.zoneId)

      // send over zone and characters to socket
      socket.emit('gm:zone_editor:zone:load', zone)
    } catch (error: any) {
      console.log(`---Error updating zone: ${error.message}`)
    }
  })
}
