import prisma from '../utilities/Prisma' // Import the global Prisma instance
import { Sprite } from '@prisma/client'

class SpriteRepository {
  async getById(id: string): Promise<Sprite | null> {
    return prisma.sprite.findUnique({
      where: { id }
    })
  }

  async getAll(): Promise<Sprite[]> {
    return prisma.sprite.findMany()
  }

  async create(name: string, origin_x: number, origin_y: number): Promise<Sprite> {
    return prisma.sprite.create({
      data: {
        name,
        origin_x,
        origin_y
      }
    })
  }

  async update(id: string, name: string, origin_x: number, origin_y: number): Promise<Sprite> {
    return prisma.sprite.update({
      where: { id },
      data: {
        name,
        origin_x,
        origin_y
      }
    })
  }

  async delete(id: string): Promise<Sprite> {
    return prisma.sprite.delete({
      where: { id }
    })
  }
}

export default new SpriteRepository()
