import prisma from '../utilities/Prisma' // Import the global Prisma instance
import { Tile } from '@prisma/client'

class TileRepository {
  async getById(id: string): Promise<Tile | null> {
    return prisma.tile.findUnique({
      where: { id }
    })
  }

  async getAll(): Promise<Tile[]> {
    return prisma.tile.findMany()
  }

  async create(name: string): Promise<Tile> {
    return prisma.tile.create({
      data: {
        name,
        tags: []
      }
    })
  }

  async update(id: string, name: string, tags: string[]): Promise<Tile> {
    return prisma.tile.update({
      where: { id },
      data: {
        name,
        tags
      }
    })
  }

  async delete(id: string): Promise<boolean> {
    try {
      await prisma.tile.delete({
        where: { id }
      })
      return true
    } catch (error) {
      console.log('Error deleting tile:', error)
      return false
    }
  }
}

export default new TileRepository()
